@@ -1,7 +1,7 @@
 #!/usr/bin/python3
-# Copyright (c) 2017-2018 David Steele <dsteele@gmail.com>
+# Copyright (c) 2017-2019 David Steele <dsteele@gmail.com>
 #
-# SPDX-License-Identifier: GPL-2+
+# SPDX-License-Identifier: GPL-2.0-or-later
 # License-Filename: LICENSE
 
 #
@@ -14,6 +14,7 @@
 import dbus
 import sys
 
+
 class CiuClient(object):
 
     # Make the dbus functions late binding, to facilitate testing.
@@ -40,8 +41,10 @@ class CiuClient(object):
                 bus = dbus.SystemBus()
                 self.service = bus.get_object('com.github.davesteele.comitup',
                                               '/com/github/davesteele/comitup')
-            func = self.service.get_dbus_method(self.methods[name],
-                                                'com.github.davesteele.comitup')
+            func = self.service.get_dbus_method(
+                    self.methods[name],
+                    'com.github.davesteele.comitup'
+                    )
         except dbus.exceptions.DBusException:
             sys.exit(1)
 
