@@ -1,7 +1,7 @@
 #!/usr/bin/python3
-# Copyright (c) 2017 David Steele <dsteele@gmail.com>
+# Copyright (c) 2017-2019 David Steele <dsteele@gmail.com>
 #
-# SPDX-License-Identifier: GPL-2+
+# SPDX-License-Identifier: GPL-2.0-or-later
 # License-Filename: LICENSE
 
 #
@@ -16,6 +16,8 @@ import dbus.service
 import logging
 from comitup import iwscan
 import os
+import re
+import socket
 import subprocess
 
 import sys
@@ -23,7 +25,7 @@ sys.path.append("/usr/share/comitup")
 
 import pkg_resources                          # noqa
 
-from gi.repository.GLib import MainLoop        # noqa
+from gi.repository.GLib import MainLoop, timeout_add       # noqa
 import time                                   # noqa
 from dbus.mainloop.glib import DBusGMainLoop  # noqa
 DBusGMainLoop(set_as_default=True)
@@ -76,25 +78,32 @@ class Comitup(dbus.service.Object):
 
     @dbus.service.method(comitup_int, in_signature="ss", out_signature="")
     def connect(self, ssid, password):
-        if nm.get_connection_by_ssid(ssid):
-            nm.del_connection_by_ssid(ssid)
+        def to_fn(ssid, password):
+            if nm.get_connection_by_ssid(ssid):
+                nm.del_connection_by_ssid(ssid)
 
-        nm.make_connection_for(ssid, password)
+            nm.make_connection_for(ssid, password)
 
-        states.set_state('CONNECTING', [ssid, ssid])
+            states.set_state('CONNECTING', [ssid, ssid])
+            return False
+
+        timeout_add(1, to_fn, ssid, password)
 
     @dbus.service.method(comitup_int, in_signature="", out_signature="")
     def delete_connection(self):
-        ssid = nm.get_active_ssid(modemgr.get_link_device())
-        nm.del_connection_by_ssid(ssid)
-        states.set_state('HOTSPOT')
+        def to_fn():
+            ssid = nm.get_active_ssid(modemgr.get_link_device())
+            nm.del_connection_by_ssid(ssid)
+            states.set_state('HOTSPOT')
+            return False
+
+        timeout_add(1, to_fn)
 
     @dbus.service.method(comitup_int, in_signature="", out_signature="a{ss}")
     def get_info(self):
         info = {
             'version': pkg_resources.get_distribution("comitup").version,
-            'basename': conf.base_name,
-            'id': data.id,
+            'apname': expand_ap(conf.ap_name, data.id),
             'hostnames': ';'.join(get_hosts(conf, data)),
             'imode': modemgr.get_mode(),
             }
@@ -102,9 +111,20 @@ class Comitup(dbus.service.Object):
         return info
 
 
+def expand_ap(ap_name, id):
+    returnval = ap_name
+
+    for l in range(5):
+        returnval = re.sub("<{}>".format("n"*l), id[:l], returnval)
+
+    returnval = re.sub("<hostname>", socket.gethostname(), returnval)
+
+    return returnval
+
+
 def get_hosts(conf, data):
     return [
-        "%s-%s.local" % (conf.base_name, data.id),
+        "{}.local".format(expand_ap(conf.ap_name, data.id)),
     ]
 
 
@@ -123,12 +143,13 @@ def external_callback(state, action):
 
     def demote(uid, gid):
         def dodemote():
-            os.setuid(uid)
+            os.setgroups([])
             os.setgid(gid)
+            os.setuid(uid)
 
         return dodemote
 
-    stats= os.stat(script)
+    stats = os.stat(script)
 
     with open(os.devnull, 'w') as nul:
         subprocess.call(
@@ -144,11 +165,13 @@ def init_state_mgr(gconf, gdata, callbacks):
 
     conf, data = (gconf, gdata)
 
-    states.init_states(get_hosts(conf, data), callbacks + [external_callback])
+    states.init_states(
+        get_hosts(conf, data),
+        callbacks + [external_callback],
+        conf.ap_password
+    )
     com_obj = Comitup()
 
-    states.set_state('HOTSPOT', timeout=5)
-
 
 def main():
     handler = logging.StreamHandler(stream=None)
