@@ -7,6 +7,7 @@ pkgs = [
     "libcairo2-dev",
     "gobject-introspection",
     "libgirepository1.0-dev",
+    "python3-dev",
 ]
 
 deps = [
@@ -26,10 +27,7 @@ def missing_pkg(pkg):
 def test(session):
     missings = [x for x in pkgs if missing_pkg(x)]
     if missings:
-        print("Missing packages")
-        for pkg in missings:
-            print("    {}".format(pkg))
-        sys.exit(1)
+        session.error("Missing packages: %s" % format(", ".join(missings)))
 
     for pkg in deps:
         session.install(pkg)
